SystemOrganization addCategory: #'Magritte-Tests-Core'!
SystemOrganization addCategory: #'Magritte-Tests-Description'!
SystemOrganization addCategory: #'Magritte-Tests-Accessor'!
SystemOrganization addCategory: #'Magritte-Tests-Relation'!
SystemOrganization addCategory: #'Magritte-Tests-Utility'!
SystemOrganization addCategory: #'Magritte-Tests-OmniBase'!

TestCase subclass: #MATestCase
	instanceVariableNames: 'notifications'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Core'!

MATestCase subclass: #MADynamicObjectTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Utility'!

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 3/21/2005 20:10'!
testCalculated
	| object dummy |
	object := MADynamicObject on: [ Time millisecondClockValue ].
	dummy := object yourself.
	
	(Delay forMilliseconds: 2) wait.
	self assert: dummy < object.! !

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 3/19/2005 20:35'!
testCollection
	| object |
	object := MADynamicObject on: [ OrderedCollection with: 1 with: 2 ].
	self assert: object size = 2.
	self assert: object first = 1.
	self assert: object second = 2.
	
	object add: 3.
	self assert: object size = 2.
	self assert: object first = 1.
	self assert: object second = 2.! !

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 3/19/2005 20:35'!
testConstant
	| object |
	object := MADynamicObject on: [ self ].
	self assert: object = self.
	
	object := MADynamicObject on: [ 123 ].
	self assert: object = 123.! !

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 4/9/2005 12:48'!
testNull
	| object |
	object := MADynamicObject on: 'abc'.
	self deny: object isNil.
	self assert: object notNil.
	
	object := MADynamicObject on: nil.
	self assert: object isNil.
	self deny: object notNil.! !

MATestCase subclass: #MAObjectTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Core'!

MAObjectTest subclass: #MADescriptionTest
	instanceVariableNames: 'description'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MADescriptionTest subclass: #MAContainerTest
	instanceVariableNames: 'child1 child2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAContainerTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MAContainerTest methodsFor: 'accessing' stamp: 'lr 3/27/2005 11:03'!
child1
	child1 isNil
		ifTrue: [ child1 := MAStringDescription selector: #child1 label: 'child1' priority: 1 ].
	^child1.! !

!MAContainerTest methodsFor: 'accessing' stamp: 'lr 3/27/2005 11:02'!
child2
	child2 isNil
		ifTrue: [ child2 := MAStringDescription selector: #child2 label: 'child2'  priority: 2 ].
	^child2.! !

!MAContainerTest methodsFor: 'testing-adding' stamp: 'lr 3/24/2005 10:05'!
testAdd
	self description add: self child1.
	self assert: (self description size = 1).
	self assert: (self description includes: self child1).
	
	self description add: self child2.
	self assert: (self description size = 2).
	self assert: (self description includes: self child1).
	self assert: (self description includes: self child2).
	
	! !

!MAContainerTest methodsFor: 'testing-adding' stamp: 'lr 3/24/2005 10:05'!
testAddAll
	self description addAll: (Array 
		with: self child1 
		with: self child2).
	
	self assert: (self description size = 2).
	self assert: (self description includes: self child1).
	self assert: (self description includes: self child2).
! !

!MAContainerTest methodsFor: 'testing-converting' stamp: 'lr 4/9/2005 00:17'!
testAsContainer
	self assert: self description asContainer = self description.
	self assert: self description asContainer == self description.! !

!MAContainerTest methodsFor: 'testing-accessing' stamp: 'lr 3/24/2005 10:02'!
testChildren
	self assert: self description children isCollection.
	self assert: self description children isEmpty.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 4/9/2005 00:19'!
testCollect
	| collected |
	self description add: self child1; add: self child2.
	collected := self description collect: [ :each | each ].
	
	self assert: self description ~= collected.
	self assert: self description size = collected size.
	self assert: self description children first = self description children first.
	self assert: self description children second = self description children second.! !

!MAContainerTest methodsFor: 'testing-operators' stamp: 'lr 3/24/2005 12:26'!
testConcatenation
	| concatenate |
	concatenate := self description , self child1.
	self assert: concatenate size = 1.
	self assert: concatenate children first = self child1.
	
	concatenate := concatenate , self child2 asContainer.
	self assert: concatenate size = 2.
	self assert: concatenate children first = self child1.
	self assert: concatenate children second = self child2.! !

!MAContainerTest methodsFor: 'testing-copying' stamp: 'lr 4/8/2005 23:41'!
testCopy
	self description add: self child1; add: self child2.
	super testCopy.
	
	self deny: self description copy children == self description children.
	self assert: self description copy children first = self description children first.
	self assert: self description copy children second = self description children second.! !

!MAContainerTest methodsFor: 'testing-copying' stamp: 'lr 3/24/2005 12:10'!
testCopyFromTo
	| copied |
	self description add: self child1; add: self child2.
	copied := self description copyFrom: 1 to: 1.
	
	self assert: copied ~= self description.
	self assert: copied size = 1.
	self assert: copied children first = self description children first.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 3/24/2005 10:45'!
testDetect
	self description add: self child1.
	self assert: (self description 
		detect: [ :each | self child1 = each ]) = self child1.
	self should: [ self description 
		detect: [ :each | self child2 = each ] ] raise: Error.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 3/24/2005 10:45'!
testDetectIfNone
	self description add: self child1.
	self assert: (self description 
		detect: [ :each | self child1 = each ] 
		ifNone: [ 123 ]) = self child1.
	self assert: (self description 
		detect: [ :each | self child2 = each ] 
		ifNone: [ 123 ]) = 123.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 3/24/2005 10:43'!
testDo
	| collection |
	collection := self description class defaultCollection.
	self description add: self child1; add: self child2.
	self description do: [ :each | collection add: each ].
	self assert: (self description children hasEqualElements: collection).! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 3/24/2005 10:45'!
testDoSepratedBy
	| collection |
	collection := OrderedCollection new.
	self description add: self child1; add: self child2.
	self description 
		do: [ :each | collection add: each ]
		separatedBy: [ collection add: nil ].
	self assert: collection size = 3.
	self assert: collection first = self child1.
	self assert: collection second isNil.
	self assert: collection third = self child2.! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 3/24/2005 10:09'!
testEmpty
	self assert: self description isEmpty.
	self description add: self child1.
	self deny: self description isEmpty.! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 4/6/2005 20:56'!
testHasChildren
	super testHasChildren.
	self description add: self child1.
	self assert: self description hasChildren.! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 3/24/2005 10:08'!
testIncludes
	self deny: (self description includes: self child1).
	self description add: self child1.
	self assert: (self description includes: self child1).! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 3/27/2005 11:00'!
testInjectInto
	self description add: self child1; add: self child2.
	self assert: (self description 
		inject: 'start'
		into: [ :result :each | result , ' ' , each label ]) = 'start child1 child2'.! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 4/6/2005 20:57'!
testIsContainer
	self assert: self description isContainer.! !

!MAContainerTest methodsFor: 'testing-moving' stamp: 'lr 3/24/2005 10:12'!
testMoveDown
	self description add: self child1; add: self child2.
	self assert: self description children first = self child1.
	self assert: self description children second = self child2.
	
	self description moveDown: self child1.
	self assert: self description children first = self child2.
	self assert: self description children second = self child1.
	
	self description moveDown: self child1.
	self assert: self description children first = self child1.
	self assert: self description children second = self child2.
	! !

!MAContainerTest methodsFor: 'testing-moving' stamp: 'lr 3/24/2005 10:11'!
testMoveUp
	self description add: self child1; add: self child2.
	self assert: self description children first = self child1.
	self assert: self description children second = self child2.
	
	self description moveUp: self child2.
	self assert: self description children first = self child2.
	self assert: self description children second = self child1.
	
	self description moveUp: self child2.
	self assert: self description children first = self child1.
	self assert: self description children second = self child2.
	! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 3/24/2005 10:09'!
testNotEmpty
	self deny: self description notEmpty.
	self description add: self child1.
	self assert: self description notEmpty.! !

!MAContainerTest methodsFor: 'testing-indentity' stamp: 'lr 4/9/2005 00:23'!
testReferenceStream
	| object |
	self description add: self child1; add: self child2.
	object := super testReferenceStream.
	
	self assert: object children first = self child1.
	self deny: object children first == self child1.
	
	self assert: object children second = self child2.
	self deny: object children second == self child2.
! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 3/24/2005 12:11'!
testReject
	| rejected |
	self description add: self child1; add: self child2.
	rejected := self description reject: [ :each | false ].
	
	self assert: self description ~= rejected.
	self assert: self description size = rejected size.
	self assert: self description children first = rejected children first.
	self assert: self description children second = rejected children second.! !

!MAContainerTest methodsFor: 'testing-removing' stamp: 'lr 3/24/2005 10:07'!
testRemove
	self description add: self child1; add: self child2.

	self description remove: self child1.
	self assert: self description size = 1.
	self deny: (self description includes: self child1).
	self assert: (self description includes: self child2).

	self description remove: self child2.
	self assert: self description isEmpty.! !

!MAContainerTest methodsFor: 'testing-removing' stamp: 'lr 3/24/2005 10:07'!
testRemoveAll
	self description add: self child1; add: self child2.

	self description removeAll.
	self assert: self description isEmpty.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 3/24/2005 12:11'!
testSelect
	| selected |
	self description add: self child1; add: self child2.
	selected := self description select: [ :each | true ].
	
	self assert: self description ~= selected.
	self assert: self description size = selected size.
	self assert: self description children first = selected children first.
	self assert: self description children second = selected children second.! !

!MAContainerTest methodsFor: 'testing-accessing' stamp: 'lr 3/24/2005 10:03'!
testSize
	self assert: self description size isZero.
	self description add: self child1.
	self assert: self description size = 1.
	self description add: self child2.
	self assert: self description size = 2.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 4/6/2005 21:25'!
testWithIndexDo
	self description add: self child1; add: self child2.
	self description withIndexDo: [ :each :index | 
		index = 1
			ifTrue: [ self assert: self child1 = each ]
			ifFalse: [
				index = 2
					ifTrue: [ self assert: self child2 = each ]
					ifFalse: [ self assert: false ] ] ].! !

!MAContainerTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MAContainer! !

MAContainerTest subclass: #MAPriorityContainerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAPriorityContainerTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MAPriorityContainerTest methodsFor: 'testing-moving' stamp: 'lr 4/6/2005 22:19'!
testMoveDown
	self description add: self child1; add: self child2.
	self assert: self description children first = self child1.
	self assert: self description children second = self child2.
	self assert: self child2 priority = 2.
	
	self description moveDown: self child2; moveDown: self child2.
	self assert: self description children first = self child2.
	self assert: self description children second = self child1.
	self assert: self child2 priority = 0.! !

!MAPriorityContainerTest methodsFor: 'testing-moving' stamp: 'lr 4/6/2005 22:13'!
testMoveUp
	self description add: self child1; add: self child2.
	self assert: self description children first = self child1.
	self assert: self description children second = self child2.
	self assert: self child1 priority = 1.
	
	self description moveUp: self child1; moveUp: self child1.
	self assert: self description children first = self child2.
	self assert: self description children second = self child1.
	self assert: self child1 priority = 3.! !

!MAPriorityContainerTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MAPriorityContainer! !

MAContainerTest subclass: #MAReportContainerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAReportContainerTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MAReportContainerTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MAReportContainer! !

!MADescriptionTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^true! !

!MADescriptionTest class methodsFor: 'testing' stamp: 'lr 3/11/2005 22:47'!
shouldInheritSelectors
	^true! !

!MADescriptionTest methodsFor: 'accessing' stamp: 'lr 4/9/2005 16:33'!
description
	^description! !

!MADescriptionTest methodsFor: 'private' stamp: 'lr 4/9/2005 16:39'!
descriptionInstance
	^self testedClass new.! !

!MADescriptionTest methodsFor: 'accessing' stamp: 'lr 4/9/2005 16:33'!
instance
	^description! !

!MADescriptionTest methodsFor: 'running' stamp: 'lr 4/9/2005 16:34'!
setUp
	super setUp.
	description := self descriptionInstance.! !

!MADescriptionTest methodsFor: 'testing-converting' stamp: 'lr 4/9/2005 12:34'!
testAsContainer
	self subclassResponsibility.! !

!MADescriptionTest methodsFor: 'testing-converting' stamp: 'lr 4/6/2005 21:05'!
testAsLabel
	self assert: self description asLabel = self description asString.
	
	self description label: 'foo'.
	self assert: self description asLabel = 'foo'.! !

!MADescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 4/9/2005 00:09'!
testComment
	self description comment: 'bar'.
	self assert: self description comment = 'bar'.! !

!MADescriptionTest methodsFor: 'testing-copying' stamp: 'lr 4/8/2005 23:32'!
testCopy
	| copy |
	copy := self description copy.
		
	self deny: self description = copy.
	self deny: self description properties == copy properties.
	
	self assert: self description properties = copy properties.
	self assert: self description properties size = copy properties size.! !

!MADescriptionTest methodsFor: 'testing-testing' stamp: 'lr 4/6/2005 20:55'!
testHasChildren
	self deny: self description hasChildren.! !

!MADescriptionTest methodsFor: 'testing-testing' stamp: 'lr 3/27/2005 12:00'!
testHasComment
	self description comment: nil.
	self deny: self description hasComment.
	
	self description comment: ''.
	self deny: self description hasComment.
	
	self description comment: 'comment'.
	self assert:  self description hasComment.! !

!MADescriptionTest methodsFor: 'testing-testing' stamp: 'lr 3/27/2005 12:00'!
testHasLabel
	self description label: nil.
	self deny: self description hasLabel.
	
	self description label: ''.
	self deny: self description hasLabel.
	
	self description label: 'label'.
	self assert:  self description hasLabel.! !

!MADescriptionTest methodsFor: 'testing-testing' stamp: 'lr 4/6/2005 20:57'!
testIsContainer
	self deny: self description isContainer.! !

!MADescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 3/27/2005 11:08'!
testLabel
	self description label: 'foo'.
	self assert: self description label = 'foo'.! !

!MADescriptionTest methodsFor: 'testing-actions' stamp: 'lr 4/6/2005 21:09'!
testPersistent
	self description beEphemeral.
	self deny: self description persistent.
	self deny: self description isPersistent.
	
	self description bePersistent.
	self assert: self description persistent.
	self assert: self description isPersistent.! !

!MADescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 4/9/2005 00:09'!
testPriority
	self description priority: 123.
	self assert: self description priority = 123.! !

!MADescriptionTest methodsFor: 'testing-actions' stamp: 'lr 4/6/2005 21:12'!
testReadonly
	self description beReadonly.
	self assert: self description readonly.
	self assert: self description isReadonly.
	
	self description beWriteable.
	self deny: self description readonly.
	self deny: self description isReadonly.! !

!MADescriptionTest methodsFor: 'testing-actions' stamp: 'lr 4/6/2005 21:11'!
testRequired
	self description beRequired.
	self assert: self description required.
	self assert: self description isRequired.
	
	self description beOptional.
	self deny: self description required.
	self deny: self description isRequired.
! !

!MADescriptionTest methodsFor: 'testing-actions' stamp: 'lr 4/6/2005 21:09'!
testVisible
	self description beHidden.
	self deny: self description visible.
	self deny: self description isVisible.
	
	self description beVisible.
	self assert: self description visible.
	self assert: self description isVisible.
! !

!MADescriptionTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MADescription! !

MADescriptionTest subclass: #MAElementDescriptionTest
	instanceVariableNames: 'wrapper value'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MAElementDescriptionTest subclass: #MABinaryDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MABinaryDescriptionTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MABinaryDescriptionTest methodsFor: 'private' stamp: 'lr 4/8/2005 23:56'!
includedInstance
	^ByteArray with: 1 with: 2 with: 3.! !

!MABinaryDescriptionTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MABinaryDescription! !

MAElementDescriptionTest subclass: #MABooleanDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MABooleanDescriptionTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MABooleanDescriptionTest methodsFor: 'private' stamp: 'lr 4/9/2005 00:12'!
includedInstance
	^true! !

!MABooleanDescriptionTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MABooleanDescription! !

!MAElementDescriptionTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^true! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 4/9/2005 16:39'!
descriptionInstance
	^self testedClass selector: #value.! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 4/8/2005 23:51'!
emptyInstance
	^String new! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 4/9/2005 12:33'!
includedInstance
	self subclassResponsibility! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 4/8/2005 23:51'!
invalidInstance
	^Object new! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 4/8/2005 23:51'!
nullInstance
	^nil! !

!MAElementDescriptionTest methodsFor: 'running' stamp: 'lr 4/8/2005 23:45'!
setUp
	super setUp.
	wrapper := self wrapperInstance.
	value := self valueInstance.! !

!MAElementDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 4/12/2005 21:45'!
testAccessor
	self assert: self description accessor selector = #value.! !

!MAElementDescriptionTest methodsFor: 'testing-converting' stamp: 'lr 4/8/2005 23:50'!
testAsContainer
	self assert: (self description asContainer size) = 1.
	self assert: (self description asContainer includes: self description).! !

!MAElementDescriptionTest methodsFor: 'testing-operators' stamp: 'lr 4/8/2005 23:50'!
testConcatenation
	| child1 child2 concatenate |
	child1 := self description copy.
	child2 := self description copy.
	
	concatenate := child1 , child2.
	self assert: concatenate size = 2.
	self assert: concatenate children first = child1.
	self assert: concatenate children second = child2.
	
	concatenate := child1 , concatenate.
	self assert: concatenate size = 3.
	self assert: concatenate children first = child1.
	self assert: concatenate children second = child1.
	self assert: concatenate children third = child2.! !

!MAElementDescriptionTest methodsFor: 'testing-copying' stamp: 'lr 4/12/2005 21:44'!
testCopy
	super testCopy.
	self deny: self description copy accessor == self description accessor.
	self assert: self description copy default = self description default.! !

!MAElementDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 4/8/2005 23:47'!
testDefault
	self description default: self includedInstance.
	self assert: self description default = self includedInstance.! !

!MAElementDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 4/8/2005 23:48'!
testKind
	self assert: (self includedInstance isKindOf: self description kind).! !

!MAElementDescriptionTest methodsFor: 'testing-operators' stamp: 'lr 4/13/2005 20:16'!
testParseString
	self assert: (self description parseString: self nullInstance) isNil.
	self assert: (self description parseString: self emptyInstance) isNil.
	self assert: (self description isSatisfiedBy: (self description 
		parseString: (self description toString: self includedInstance))).! !

!MAElementDescriptionTest methodsFor: 'testing-model' stamp: 'lr 4/8/2005 23:53'!
testRead
	| other |
	self value: (other := self includedInstance).
	self assert: self wrapper value = other.
	
	self value: (other := self nullInstance).
	self assert: self wrapper value = self description class defaultDefault.! !

!MAElementDescriptionTest methodsFor: 'testing-testing' stamp: 'lr 4/13/2005 20:15'!
testSatisfied
	self assert: (self description isSatisfiedBy: self includedInstance).
	self deny: (self description isSatisfiedBy: self invalidInstance).
	self deny: (self description isSatisfiedBy: self nullInstance).! !

!MAElementDescriptionTest methodsFor: 'testing-operators' stamp: 'lr 4/8/2005 23:52'!
testToString
	self assert: (self description toString: self includedInstance) = self includedInstance asLabel.
	self assert: (self description toString: self nullInstance) = String new.! !

!MAElementDescriptionTest methodsFor: 'testing-testing' stamp: 'lr 4/8/2005 23:55'!
testValidates
	self shouldnt: [ self wrapper validate: self includedInstance ] raise: MAError.
	self shouldnt: [ self wrapper validate: self nullInstance ] raise: MAError.
	self should: [ self wrapper validate: self invalidInstance ] raise: MAError.! !

!MAElementDescriptionTest methodsFor: 'testing-model' stamp: 'lr 4/8/2005 23:53'!
testWrite
	| other |
	self wrapper value: (other := self includedInstance).
	self assert: self value = other.! !

!MAElementDescriptionTest methodsFor: 'testing-model' stamp: 'lr 4/8/2005 23:54'!
testWriteIncluded
	self wrapper value: self invalidInstance.
	self
		should: [ self wrapper validate; commit  ]
		raise: MAValidationError.
		
	self wrapper value: self nullInstance.
	self
		shouldnt: [ self wrapper validate; commit ]
		raise: MAValidationError.
	
	self wrapper value: self includedInstance.
	self
		shouldnt: [ self wrapper validate; commit ]
		raise: MAValidationError.! !

!MAElementDescriptionTest methodsFor: 'testing-model' stamp: 'lr 4/13/2005 20:09'!
testWriteReadonly
	self value: self includedInstance.
	self description beReadonly.
	self
		shouldnt: [ self wrapper commit ]
		raise: MAReadonlyError.

	self value: self includedInstance.
	self description beWriteable.
	self
		shouldnt: [ self wrapper commit ]
		raise: MAReadonlyError.! !

!MAElementDescriptionTest methodsFor: 'testing-model' stamp: 'lr 4/9/2005 00:09'!
testWriteRequired
	self description beRequired.
	self value: self nullInstance.
	self
		should: [ self wrapper validate; commit ]
		raise: MARequiredError.
	self value: self includedInstance.
	self
		shouldnt: [ self wrapper validate; commit ]
		raise: MARequiredError.
		
	self description beOptional.
	self value: self nullInstance.
	self
		shouldnt: [ self wrapper validate; commit ]
		raise: MARequiredError.
	self value: self includedInstance.
	self
		shouldnt: [ self wrapper validate; commit ]
		raise: MARequiredError.! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MAElementDescription! !

!MAElementDescriptionTest methodsFor: 'accessing-model' stamp: 'lr 4/8/2005 23:49'!
value
	^value! !

!MAElementDescriptionTest methodsFor: 'accessing-model' stamp: 'lr 4/8/2005 23:49'!
value: anObject
	value := anObject! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 4/8/2005 23:46'!
valueInstance
	^nil! !

!MAElementDescriptionTest methodsFor: 'accessing' stamp: 'lr 4/8/2005 23:49'!
wrapper
	^wrapper! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 4/8/2005 23:44'!
wrapperInstance
	^MAStraitWrapper on: self description model: self.! !

MAElementDescriptionTest subclass: #MAMagnitudeDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MAMagnitudeDescriptionTest subclass: #MADateDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MADateDescriptionTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MADateDescriptionTest methodsFor: 'private' stamp: 'lr 4/8/2005 23:56'!
includedInstance
	^Date newDay: 11 month: 6 year: 1980.! !

!MADateDescriptionTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MADateDescription! !

MAMagnitudeDescriptionTest subclass: #MADurationDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MADurationDescriptionTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MADurationDescriptionTest methodsFor: 'private' stamp: 'lr 4/8/2005 23:57'!
includedInstance
	^Duration days: 1 hours: 2 minutes: 3 seconds: 4.! !

!MADurationDescriptionTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MADurationDescription! !

!MAMagnitudeDescriptionTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^true! !

!MAMagnitudeDescriptionTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MAMagnitudeDescription! !

MAMagnitudeDescriptionTest subclass: #MANumberDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MANumberDescriptionTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MANumberDescriptionTest methodsFor: 'private' stamp: 'lr 4/8/2005 23:57'!
includedInstance
	^3.1415! !

!MANumberDescriptionTest methodsFor: 'testing' stamp: 'lr 4/13/2005 21:44'!
testBetweenAnd
	self description condition: [ :each | each between: -5 and: 5 ].
	
	self deny: (self description isSatisfiedBy: nil).
	self deny: (self description isSatisfiedBy: -10).
	self deny: (self description isSatisfiedBy: 10).
	
	self assert: (self description isSatisfiedBy: 0).
	! !

!MANumberDescriptionTest methodsFor: 'testing' stamp: 'lr 4/13/2005 21:43'!
testInteger
	self description condition: [ :each | each isInteger ].
	
	self deny: (self description isSatisfiedBy: nil).
	self deny: (self description isSatisfiedBy: 12.3).
	self assert: (self description isSatisfiedBy: 1234).
	! !

!MANumberDescriptionTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MANumberDescription! !

MAMagnitudeDescriptionTest subclass: #MATimeDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MATimeDescriptionTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MATimeDescriptionTest methodsFor: 'private' stamp: 'lr 4/8/2005 23:58'!
includedInstance
	^Time hour: 11 minute: 33 second: 12.! !

!MATimeDescriptionTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MATimeDescription! !

MAMagnitudeDescriptionTest subclass: #MATimeStampDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MATimeStampDescriptionTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MATimeStampDescriptionTest methodsFor: 'private' stamp: 'lr 4/8/2005 23:58'!
includedInstance
	^TimeStamp year: 1980 month: 6 day: 1980 hour: 11 minute: 38 second: 12.! !

!MATimeStampDescriptionTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MATimeStampDescription! !

MAElementDescriptionTest subclass: #MAOptionsDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAOptionsDescriptionTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MAOptionsDescriptionTest methodsFor: 'private' stamp: 'lr 4/9/2005 00:14'!
includedInstance
	^self optionInstances second.! !

!MAOptionsDescriptionTest methodsFor: 'private' stamp: 'lr 4/9/2005 00:14'!
optionInstances
	^Array with: 'Option1' with: 'Option2' with: 'Option3'.
	! !

!MAOptionsDescriptionTest methodsFor: 'running' stamp: 'lr 4/9/2005 02:36'!
setUp
	super setUp.
	self description options: self optionInstances.! !

!MAOptionsDescriptionTest methodsFor: 'testing-copying' stamp: 'lr 4/9/2005 02:31'!
testCopy
	| copy |
	super testCopy.
	copy := self description copy.
	self deny: copy options == self description options.
	self assert: copy options = self description options.
! !

!MAOptionsDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 4/12/2005 14:31'!
testNone
	self description nilLabel: 'none'.
	self assert: self description nilLabel = 'none'.! !

!MAOptionsDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 4/9/2005 02:31'!
testOptions
	self description options: #( a b c ).
	self assert: self description options = #( a b c ).! !

!MAOptionsDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 4/9/2005 02:31'!
testOptionsTextual
	self description options: #( 'a' 'b' ).
	self assert: self description optionsTextual = 'a
b'.

	self description optionsTextual: 'x
y'.
	self assert: self description options asArray = #( 'x' 'y' ).! !

!MAOptionsDescriptionTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MAOptionsDescription! !

MAElementDescriptionTest subclass: #MAStringDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MAStringDescriptionTest subclass: #MAPasswordDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAPasswordDescriptionTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MAPasswordDescriptionTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MAPasswordDescription! !

!MAStringDescriptionTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MAStringDescriptionTest methodsFor: 'private' stamp: 'lr 4/9/2005 00:15'!
includedInstance
	^ 'Lukas Renggli'! !

!MAStringDescriptionTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MAStringDescription! !

MAStringDescriptionTest subclass: #MASymbolDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MASymbolDescriptionTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MASymbolDescriptionTest methodsFor: 'private' stamp: 'lr 4/9/2005 00:02'!
includedInstance
	^ #magritte! !

!MASymbolDescriptionTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MASymbolDescription! !

MAStringDescriptionTest subclass: #MATextDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MATextDescriptionTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MATextDescriptionTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MATextDescription! !

MAElementDescriptionTest subclass: #MATableDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MATableDescriptionTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MATableDescriptionTest methodsFor: 'private' stamp: 'lr 4/9/2005 00:05'!
includedInstance
	^ #( 'a1' 'a2' 'b1' 'b2' 'c1' 'c2' )! !

!MATableDescriptionTest methodsFor: 'private' stamp: 'lr 4/9/2005 00:04'!
invalidInstance
	^ #( 'a' 'b' 'c' 'd' 'e' )! !

!MATableDescriptionTest methodsFor: 'running' stamp: 'lr 4/9/2005 00:02'!
setUp
	super setUp.
	self description 
		columnLabels: #( a b );
		rowLabels: #( x y z ).! !

!MATableDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 4/9/2005 00:03'!
testCellCount
	self assert: self description cellCount = 6.! !

!MATableDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 4/9/2005 00:03'!
testCellDescription
	| other |
	self description cellDescription: (other := MANumberDescription new).
	self assert: self description cellDescription = other.! !

!MATableDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 4/9/2005 00:03'!
testColumnCount
	self assert: self description columnCount = 2.! !

!MATableDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 4/9/2005 00:03'!
testColumnLabels
	self description columnLabels: #( '1' '2' ).
	self assert: self description columnLabels = #( '1' '2' ).! !

!MATableDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 4/9/2005 00:03'!
testColumnLabelsTextual
	self description columnLabels: #( '1' '2' ).
	self assert: self description columnLabelsTextual = '1
2'.

	self description columnLabelsTextual: '2
1'.
	self assert: self description columnLabels asArray = #( '2' '1' ).! !

!MATableDescriptionTest methodsFor: 'testing-copying' stamp: 'lr 4/9/2005 00:04'!
testCopy
	| copy |
	super testCopy.
	copy := self description copy.
	self deny: copy rowLabels == self description rowLabels.
	self assert: copy rowLabels = self description rowLabels.
	self deny: copy columnLabels == self description columnLabels.
	self assert: copy columnLabels = self description columnLabels.
	self deny: copy cellDescription == self description cellDescription.! !

!MATableDescriptionTest methodsFor: 'testing-converting' stamp: 'lr 4/9/2005 00:03'!
testParseString! !

!MATableDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 4/9/2005 00:03'!
testRowCount
	self assert: self description rowCount = 3.! !

!MATableDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 4/9/2005 00:03'!
testRowLabels
	self description rowLabels: #( '1' '2' ).
	self assert: self description rowLabels = #( '1' '2' ).! !

!MATableDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 4/9/2005 00:03'!
testRowLabelsTextual
	self description rowLabels: #( '1' '2' ).
	self assert: self description rowLabelsTextual = '1
2'.

	self description rowLabelsTextual: '2
1'.
	self assert: self description rowLabels asArray = #( '2' '1' ).! !

!MATableDescriptionTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MATableDescription! !

MAObjectTest subclass: #MAModelAccessorTest
	instanceVariableNames: 'accessor value'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

MAModelAccessorTest subclass: #MABlockAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MABlockAccessorTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MABlockAccessorTest methodsFor: 'private' stamp: 'lr 4/11/2005 11:23'!
accessorInstance
	^self testedClass
		read: [ :model | model value ]
		write: [ :model :object | model value: object ].! !

!MABlockAccessorTest methodsFor: 'testing-testing' stamp: 'lr 4/11/2005 11:16'!
testCanRead
	self assert: self instance canRead.
	self instance readBlock: nil.
	self deny: self instance canRead.! !

!MABlockAccessorTest methodsFor: 'testing-testing' stamp: 'lr 4/11/2005 11:16'!
testCanWrite
	self assert: self instance canWrite.
	self instance writeBlock: nil.
	self deny: self instance canWrite.! !

!MABlockAccessorTest methodsFor: 'testing' stamp: 'lr 3/30/2005 21:44'!
testRead
	self value: 123.
	self assert: (self accessor read: self) = 123.
	
	self value: '12'.
	self assert: (self accessor read: self) = '12'.
! !

!MABlockAccessorTest methodsFor: 'testing' stamp: 'lr 3/30/2005 21:52'!
testReadBlock
	self accessor readBlock: [ :model |
		self assert: model = self. 123 ].
	self assert: (self accessor read: self) = 123.! !

!MABlockAccessorTest methodsFor: 'testing-identity' stamp: 'lr 4/11/2005 11:24'!
testReferenceStream
	"The class BlockContext is not serializeable, ignore this test."! !

!MABlockAccessorTest methodsFor: 'testing' stamp: 'lr 3/30/2005 21:44'!
testWrite
	self accessor write: 123 to: self.
	self assert: self value = 123.
	
	self accessor write: '123' to: self.
	self assert: self value = '123'.
! !

!MABlockAccessorTest methodsFor: 'testing' stamp: 'lr 3/30/2005 21:51'!
testWriteBlock
	self accessor writeBlock: [ :model :object |
		self assert: model = self.
		self assert: object = 123 ].
	self accessor write: 123 to: self.! !

!MABlockAccessorTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MABlockAccessor! !

MAModelAccessorTest subclass: #MACascadeAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MACascadeAccessorTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MACascadeAccessorTest methodsFor: 'private' stamp: 'lr 4/9/2005 02:22'!
accessorInstance
	^self testedClass selectors: #( holder contents value ).! !

!MACascadeAccessorTest methodsFor: 'private' stamp: 'lr 4/5/2005 20:52'!
holder
	^ValueHolder new 
		contents: self;
		yourself.! !

!MACascadeAccessorTest methodsFor: 'testing-testing' stamp: 'lr 4/11/2005 11:26'!
testCanRead
	self assert: self accessor canRead.
	self accessor next next readSelector: nil.
	self deny: self accessor canRead.! !

!MACascadeAccessorTest methodsFor: 'testing-testing' stamp: 'lr 4/11/2005 11:25'!
testCanWrite
	self assert: self accessor canWrite.
	self accessor next next writeSelector: nil.
	self deny: self accessor canWrite.! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 4/5/2005 20:58'!
testKind
	self assert: (self accessor isKindOf: MACascadeAccessor).
	self assert: (self accessor accessor isKindOf: MASelectorAccessor).
	self assert: (self accessor next isKindOf: MACascadeAccessor).
	self assert: (self accessor next accessor isKindOf: MASelectorAccessor).
	self assert: (self accessor next next isKindOf: MASelectorAccessor).! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 3/30/2005 22:06'!
testRead
	self value: 123.
	self assert: (self accessor read: self) = 123.
	
	self value: '12'.
	self assert: (self accessor read: self) = '12'.! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 4/5/2005 21:00'!
testSelector
	self assert: self accessor accessor selector = #holder.
	self assert: self accessor next accessor selector = #contents.
	self assert: self accessor next next selector = #value.! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 3/30/2005 22:07'!
testWrite
	self accessor write: 123 to: self.
	self assert: self value = 123.
	
	self accessor write: '123' to: self.
	self assert: self value = '123'.
! !

!MACascadeAccessorTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MACascadeAccessor! !

MAModelAccessorTest subclass: #MAContainerAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MAContainerAccessorTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MAContainerAccessorTest methodsFor: 'private' stamp: 'lr 4/9/2005 02:22'!
accessorInstance
	^self testedClass new.! !

!MAContainerAccessorTest methodsFor: 'testing-testing' stamp: 'lr 4/11/2005 11:32'!
testCanRead
	self assert: self accessor canRead.! !

!MAContainerAccessorTest methodsFor: 'testing-testing' stamp: 'lr 4/11/2005 11:32'!
testCanWrite
	self deny: self accessor canWrite.! !

!MAContainerAccessorTest methodsFor: 'testing' stamp: 'lr 4/5/2005 21:04'!
testRead
	self assert: (self accessor read: 123) = 123.! !

!MAContainerAccessorTest methodsFor: 'testing' stamp: 'lr 4/5/2005 21:04'!
testWrite
	self 	
		should: [ self accessor write: 123 to: self ] 
		raise: Error.
	self assert: self value isNil.! !

!MAContainerAccessorTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MAContainerAccessor! !

!MAModelAccessorTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^true! !

!MAModelAccessorTest methodsFor: 'accessing' stamp: 'lr 4/11/2005 10:45'!
accessor
	^accessor! !

!MAModelAccessorTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:19'!
accessorInstance
	self subclassResponsibility.! !

!MAModelAccessorTest methodsFor: 'accessing' stamp: 'lr 4/11/2005 10:45'!
instance
	^accessor! !

!MAModelAccessorTest methodsFor: 'running' stamp: 'lr 4/11/2005 10:47'!
setUp
	super setUp.
	accessor := self accessorInstance.! !

!MAModelAccessorTest methodsFor: 'testing-testing' stamp: 'lr 4/14/2005 13:19'!
testCanRead
	self subclassResponsibility.! !

!MAModelAccessorTest methodsFor: 'testing-testing' stamp: 'lr 4/14/2005 13:19'!
testCanWrite
	self subclassResponsibility.! !

!MAModelAccessorTest methodsFor: 'testing' stamp: 'lr 4/11/2005 11:22'!
testRead
	self accessor canRead
		ifTrue: [ self error: 'Missing read test' ].! !

!MAModelAccessorTest methodsFor: 'testing' stamp: 'lr 4/11/2005 11:22'!
testWrite
	self accessor canWrite
		ifTrue: [ self error: 'Missing write test' ].! !

!MAModelAccessorTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MAModelAccessor! !

!MAModelAccessorTest methodsFor: 'accessing-model' stamp: 'lr 4/11/2005 10:47'!
value
	^value! !

!MAModelAccessorTest methodsFor: 'accessing-model' stamp: 'lr 4/11/2005 10:47'!
value: anObject
	value := anObject! !

MAModelAccessorTest subclass: #MANullAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MANullAccessorTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MANullAccessorTest methodsFor: 'private' stamp: 'lr 4/9/2005 02:22'!
accessorInstance
	^self testedClass new.! !

!MANullAccessorTest methodsFor: 'testing-testing' stamp: 'lr 4/11/2005 11:30'!
testCanRead
	self deny: self accessor canRead.! !

!MANullAccessorTest methodsFor: 'testing-testing' stamp: 'lr 4/11/2005 11:30'!
testCanWrite
	self deny: self accessor canWrite.! !

!MANullAccessorTest methodsFor: 'testing' stamp: 'lr 3/30/2005 22:20'!
testRead
	self 
		should: [ self accessor read: self ]
		raise: Error.! !

!MANullAccessorTest methodsFor: 'testing' stamp: 'lr 3/30/2005 22:20'!
testWrite
	self 	
		should: [ self accessor write: 123 to: self ] 
		raise: Error.
	self assert: self value isNil.! !

!MANullAccessorTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MANullAccessor! !

MAModelAccessorTest subclass: #MASelectorAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MASelectorAccessorTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MASelectorAccessorTest methodsFor: 'private' stamp: 'lr 4/9/2005 02:22'!
accessorInstance
	^self testedClass selector: #value.! !

!MASelectorAccessorTest methodsFor: 'testing-testing' stamp: 'lr 4/11/2005 11:28'!
testCanRead
	self assert: self accessor canRead.
	self accessor readSelector: nil.
	self deny: self accessor canRead.! !

!MASelectorAccessorTest methodsFor: 'testing-testing' stamp: 'lr 4/11/2005 11:28'!
testCanWrite
	self assert: self accessor canWrite.
	self accessor writeSelector: nil.
	self deny: self accessor canWrite.! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 3/30/2005 21:56'!
testRead
	self value: 123.
	self assert: (self accessor read: self) = 123.
	
	self value: '12'.
	self assert: (self accessor read: self) = '12'.! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 3/30/2005 21:55'!
testReadSelector
	self accessor readSelector: #contents.
	
	self assert: self accessor selector = #contents.
	self assert: self accessor readSelector = #contents.
	self assert: self accessor writeSelector = #value:.! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 3/30/2005 21:55'!
testSelector
	self accessor selector: #contents.
	
	self assert: self accessor selector = #contents.
	self assert: self accessor readSelector = #contents.
	self assert: self accessor writeSelector = #contents:.! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 3/30/2005 21:56'!
testWrite
	self accessor write: 123 to: self.
	self assert: self value = 123.
	
	self accessor write: '123' to: self.
	self assert: self value = '123'.
! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 3/30/2005 21:55'!
testWriteSelector
	self accessor writeSelector: #contents:.
	
	self assert: self accessor selector = #value.
	self assert: self accessor readSelector = #value.
	self assert: self accessor writeSelector = #contents:.! !

!MASelectorAccessorTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MASelectorAccessor! !

MAObjectTest subclass: #MAModelWrapperTest
	instanceVariableNames: 'description wrapper value'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

MAModelWrapperTest subclass: #MACachedWrapperTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MACachedWrapperTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MACachedWrapperTest methodsFor: 'testing' stamp: 'lr 4/9/2005 02:24'!
testCommit
	self wrapper value: self includedInstance.
	self assert: self wrapper hasChanged.
	
	self wrapper commit.
	self assert: self wrapper value = self includedInstance.
	self assert: self value = self includedInstance.
	self deny: self wrapper hasChanged.! !

!MACachedWrapperTest methodsFor: 'testing' stamp: 'lr 4/9/2005 02:25'!
testDefault
	self value: nil.
	self description default: self defaultInstance. 
	
	self wrapper reset.
	self assert: self wrapper value = self defaultInstance.
	self assert: self value isNil.
	
	self wrapper commit.
	self assert: self wrapper value = self defaultInstance.
	self assert: self value = self defaultInstance.
	
	self wrapper value: self includedInstance; commit.
	self assert: self wrapper value = self includedInstance.
	self assert: self value = self includedInstance.! !

!MACachedWrapperTest methodsFor: 'testing' stamp: 'lr 4/9/2005 15:31'!
testInterrupt
	self wrapper value: self includedInstance.
	[ self wrapper commit ]
		on: MACommitNotification
		do: [ :ntf | self assert: ntf isBefore ].
	self assert: self value = nil.
	
	self wrapper value: self includedInstance.
	[ self wrapper commit ]
		on: MACommitNotification
		do: [ :ntf | 
			ntf isBefore 
				ifTrue: [ ntf resume ] ].
	self assert: self value = self includedInstance.! !

!MACachedWrapperTest methodsFor: 'testing' stamp: 'lr 4/9/2005 02:21'!
testRead
	self assert: self value = self nullInstance.
	self assert: self wrapper value = self defaultInstance.
	
	self value: self includedInstance.
	self assert: self value = self includedInstance.
	self assert: self wrapper value = self defaultInstance.! !

!MACachedWrapperTest methodsFor: 'testing' stamp: 'lr 4/9/2005 02:21'!
testReset
	self value: self defaultInstance.
	self wrapper value: self includedInstance.
	self assert: self wrapper hasChanged.
	
	self wrapper reset.
	self assert: self wrapper value = self defaultInstance.
	self assert: self value = self defaultInstance.
	self deny: self wrapper hasChanged.! !

!MACachedWrapperTest methodsFor: 'testing' stamp: 'lr 4/9/2005 02:21'!
testWrite
	self value: self defaultInstance.
	self wrapper value: self includedInstance.
	self assert: self value = self defaultInstance.
	self assert: self wrapper value = self includedInstance.! !

!MACachedWrapperTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MACachedWrapper! !

MACachedWrapperTest subclass: #MACheckedWrapperTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MACheckedWrapperTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MACheckedWrapperTest methodsFor: 'testing' stamp: 'lr 4/9/2005 02:31'!
testConflictCommit
	self value: self defaultInstance.
	self assert: self wrapper original = self nullInstance.
	self deny: self wrapper hasConflict.
	
	self value: self includedInstance.
	self assert: self wrapper original = self nullInstance.
	self assert: self wrapper hasConflict.
	
	self wrapper commit.
	self assert: self wrapper original = self defaultInstance.
	self deny: self wrapper hasConflict.! !

!MACheckedWrapperTest methodsFor: 'testing' stamp: 'lr 4/13/2005 21:48'!
testConflictDefault
	self wrapper value: self includedInstance.
	self assert: self wrapper original = self nullInstance.
	self deny: self wrapper hasConflict.! !

!MACheckedWrapperTest methodsFor: 'testing' stamp: 'lr 4/9/2005 02:29'!
testConflictMerged
	self value: self includedInstance.
	self wrapper value: self includedInstance.
	self deny: self wrapper hasConflict.! !

!MACheckedWrapperTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MACheckedWrapper! !

MACheckedWrapperTest subclass: #MAOmniWrapperTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-OmniBase'!

!MAOmniWrapperTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MAOmniWrapperTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MAOmniWrapper! !

!MAModelWrapperTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^true! !

!MAModelWrapperTest methodsFor: 'accessing' stamp: 'lr 4/11/2005 10:43'!
accessor
	^self description accessor.! !

!MAModelWrapperTest methodsFor: 'private' stamp: 'lr 3/30/2005 22:22'!
accessorInstance
	^MASelectorAccessor selector: #value.! !

!MAModelWrapperTest methodsFor: 'private' stamp: 'lr 4/11/2005 10:49'!
defaultInstance
	^'Lukas Renggli'! !

!MAModelWrapperTest methodsFor: 'accessing' stamp: 'lr 4/11/2005 10:40'!
description
	^description! !

!MAModelWrapperTest methodsFor: 'private' stamp: 'lr 4/11/2005 10:42'!
descriptionInstance
	^MAStringDescription new
		default: self defaultInstance;
		accessor: self accessorInstance;
		yourself.! !

!MAModelWrapperTest methodsFor: 'private' stamp: 'lr 4/11/2005 10:50'!
includedInstance
	^'Magritte'! !

!MAModelWrapperTest methodsFor: 'accessing' stamp: 'lr 4/9/2005 16:32'!
instance
	^wrapper! !

!MAModelWrapperTest methodsFor: 'private' stamp: 'lr 4/11/2005 10:53'!
invalidInstance
	^31415! !

!MAModelWrapperTest methodsFor: 'private' stamp: 'lr 4/11/2005 10:53'!
nullInstance
	^nil! !

!MAModelWrapperTest methodsFor: 'running' stamp: 'lr 4/11/2005 10:43'!
setUp
	super setUp.
	description := self descriptionInstance.
	wrapper := self wrapperInstance.! !

!MAModelWrapperTest methodsFor: 'testing-accessing' stamp: 'lr 3/30/2005 22:25'!
testAccessor
	self assert: self wrapper accessor = self accessor.! !

!MAModelWrapperTest methodsFor: 'testing' stamp: 'lr 4/11/2005 10:51'!
testCopy
	super testCopy.
	self assert: self wrapper copy owner isNil.! !

!MAModelWrapperTest methodsFor: 'testing-accessing' stamp: 'lr 4/9/2005 02:26'!
testDefault
	self assert: self wrapper value = self defaultInstance.! !

!MAModelWrapperTest methodsFor: 'testing-accessing' stamp: 'lr 4/9/2005 02:32'!
testDescription
	self assert: self wrapper owner = self description.! !

!MAModelWrapperTest methodsFor: 'testing-errors' stamp: 'lr 4/7/2005 22:30'!
testErrorConcurrent
	self 
		should: [ self wrapper errorConcurrent ]
		raise: MAConcurrentError.
	[ self wrapper errorConcurrent ]
		on: MAConcurrentError
		do: [ :error |
			self assert: error accessor = self accessor.
			self assert: error wrapper = self wrapper.
			self assert: error description = self description ].! !

!MAModelWrapperTest methodsFor: 'testing-errors' stamp: 'lr 4/7/2005 22:30'!
testErrorReadonly
	self 
		should: [ self wrapper errorReadonly ]
		raise: MAReadonlyError.
	[ self wrapper errorReadonly ]
		on: MAReadonlyError
		do: [ :error |
			self assert: error accessor = self accessor.
			self assert: error wrapper = self wrapper.
			self assert: error description = self description ].! !

!MAModelWrapperTest methodsFor: 'testing-errors' stamp: 'lr 4/7/2005 22:29'!
testErrorRequired
	self 
		should: [ self wrapper errorRequired ]
		raise: MARequiredError.
	[ self wrapper errorRequired ]
		on: MARequiredError
		do: [ :error | 
			self assert: error accessor = self accessor.
			self assert: error wrapper = self wrapper.
			self assert: error description = self description ].! !

!MAModelWrapperTest methodsFor: 'testing-errors' stamp: 'lr 4/7/2005 22:30'!
testErrorValidation
	self 
		should: [ self wrapper errorValidation ]
		raise: MAValidationError.
	[ self wrapper errorValidation ]
		on: MAValidationError
		do: [ :error |			
			self assert: error accessor = self accessor.
			self assert: error wrapper = self wrapper.
			self assert: error description = self description ].! !

!MAModelWrapperTest methodsFor: 'testing-accessing' stamp: 'lr 3/30/2005 22:25'!
testModel
	self assert: self wrapper model = self.! !

!MAModelWrapperTest methodsFor: 'testing-notifications' stamp: 'lr 4/9/2005 15:24'!
testNotifyCommit
	self wrapper value: self includedInstance; commit.
	
	self assert: self notifications size = 2.
	
	self assert: self notifications first isBefore.
	self assert: self notifications first accessor = self accessor.
	self assert: self notifications first wrapper = self wrapper.
	self assert: self notifications first description = self description.
	
	self assert: self notifications second isAfter.
	self assert: self notifications second accessor = self accessor.
	self assert: self notifications second wrapper = self wrapper.
	self assert: self notifications second description = self description.
! !

!MAModelWrapperTest methodsFor: 'testing-notifications' stamp: 'lr 4/9/2005 15:25'!
testNotifyReset
	self wrapper value: self includedInstance; reset.
	
	self assert: self notifications size = 2.
	
	self assert: self notifications first isBefore.
	self assert: self notifications first accessor = self accessor.
	self assert: self notifications first wrapper = self wrapper.
	self assert: self notifications first description = self description.
	self assert: self notifications first class = MAResetNotification.
	
	self assert: self notifications second isAfter.
	self assert: self notifications second accessor = self accessor.
	self assert: self notifications second wrapper = self wrapper.
	self assert: self notifications second description = self description.
	self assert: self notifications second class = MAResetNotification.! !

!MAModelWrapperTest methodsFor: 'testing-notifications' stamp: 'lr 4/9/2005 15:25'!
testNotifyValidate
	self wrapper value: self includedInstance; commit.
	
	self assert: self notifications size = 2.
	
	self assert: self notifications first isBefore.
	self assert: self notifications first accessor = self accessor.
	self assert: self notifications first wrapper = self wrapper.
	self assert: self notifications first description = self description.
	self assert: self notifications first class = MACommitNotification.
	
	self assert: self notifications second isAfter.
	self assert: self notifications second accessor = self accessor.
	self assert: self notifications second wrapper = self wrapper.
	self assert: self notifications second description = self description.
	self assert: self notifications second class = MACommitNotification.! !

!MAModelWrapperTest methodsFor: 'testing' stamp: 'lr 4/11/2005 10:52'!
testOwner
	self assert: self wrapper owner = self description.! !

!MAModelWrapperTest methodsFor: 'testing-primitives' stamp: 'lr 4/9/2005 02:20'!
testPull
	self value: self nullInstance.
	self assert: self wrapper pull = self nullInstance.
	
	self value: self invalidInstance.
	self assert: self wrapper pull = self invalidInstance.
	
	self value: self includedInstance.
	self assert: self wrapper pull = self includedInstance.! !

!MAModelWrapperTest methodsFor: 'testing-primitives' stamp: 'lr 4/9/2005 02:20'!
testPush
	self wrapper push: self nullInstance.
	self assert: self value = self nullInstance.
	
	self wrapper push: self invalidInstance.
	self assert: self value = self invalidInstance.
	
	self wrapper push: self includedInstance.
	self assert: self value = self includedInstance.! !

!MAModelWrapperTest methodsFor: 'testing-validation' stamp: 'lr 4/9/2005 02:25'!
testValidateIncluded
	self wrapper value: self invalidInstance.
	self should: [ self wrapper validate ] raise: MAValidationError.
	
	self wrapper value: self includedInstance.
	self shouldnt: [ self wrapper validate ] raise: MARequiredError.! !

!MAModelWrapperTest methodsFor: 'testing-validation' stamp: 'lr 4/9/2005 02:25'!
testValidateReadonly
	self description beReadonly; beRequired.
	
	self wrapper value: self nullInstance.
	self shouldnt: [ self wrapper validate ] raise: MAReadonlyError.
	
	self wrapper value: self invalidInstance.
	self shouldnt: [ self wrapper validate ] raise: MAReadonlyError.! !

!MAModelWrapperTest methodsFor: 'testing-validation' stamp: 'lr 4/9/2005 02:25'!
testValidateRequired
	self description beRequired.
	self wrapper value: self nullInstance.
	self should: [ self wrapper validate ] raise: MARequiredError.
	
	self description beOptional.
	self wrapper value: self nullInstance.
	self shouldnt: [ self wrapper validate ] raise: MARequiredError.! !

!MAModelWrapperTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MAModelWrapper! !

!MAModelWrapperTest methodsFor: 'accessing-model' stamp: 'lr 4/11/2005 10:41'!
value
	^value! !

!MAModelWrapperTest methodsFor: 'accessing-model' stamp: 'lr 4/11/2005 10:41'!
value: anObject
	value := anObject! !

!MAModelWrapperTest methodsFor: 'accessing' stamp: 'lr 3/30/2005 22:22'!
wrapper
	^wrapper! !

!MAModelWrapperTest methodsFor: 'private' stamp: 'lr 4/11/2005 10:50'!
wrapperInstance
	^self testedClass on: self description model: self.! !

MAModelWrapperTest subclass: #MAStraitWrapperTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MAStraitWrapperTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MAStraitWrapperTest methodsFor: 'testing' stamp: 'lr 4/9/2005 02:26'!
testRead
	self assert: self wrapper value = self defaultInstance.
	
	self value: '123'.
	self assert: self wrapper value = '123'.
	
	self value: '321'.
	self assert: self wrapper value = '321'.! !

!MAStraitWrapperTest methodsFor: 'testing-validation' stamp: 'lr 4/9/2005 02:26'!
testValidateRequired
	self description beRequired.
	self wrapper value: self nullInstance.
	self shouldnt: [ self wrapper validate ] raise: MARequiredError.
	
	self description beOptional.
	self wrapper value: self nullInstance.
	self shouldnt: [ self wrapper validate ] raise: MARequiredError.! !

!MAStraitWrapperTest methodsFor: 'testing' stamp: 'lr 4/7/2005 21:52'!
testWrite
	self wrapper value: '123'.
	self assert: self value = '123'.
	
	self wrapper value: '123'.
	self assert: self value = '123'.! !

!MAStraitWrapperTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MAStraitWrapper! !

!MAObjectTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^true! !

!MAObjectTest methodsFor: 'accessing' stamp: 'lr 4/14/2005 13:23'!
instance
	self subclassResponsibility.! !

!MAObjectTest methodsFor: 'testing-copying' stamp: 'lr 4/9/2005 12:45'!
testCopy
	self assert: self instance = self instance.
	self deny: self instance = self instance copy.! !

!MAObjectTest methodsFor: 'testing-identity' stamp: 'lr 4/8/2005 23:19'!
testDictionaryKey
	| dictionary |
	dictionary := Dictionary new.
	
	dictionary at: self instance put: 1.
	self assert: (dictionary at: self instance) = 1.
	
	dictionary at: self instance copy put: 2.
	self assert: (dictionary at: self instance) = 1.
	
	dictionary at: self instance put: 3.
	self assert: (dictionary at: self instance) = 3.! !

!MAObjectTest methodsFor: 'testing-comparing' stamp: 'lr 4/8/2005 23:15'!
testEqual
	self assert: self instance = self instance.
	self deny: self instance = self instance copy.! !

!MAObjectTest methodsFor: 'testing-comparing' stamp: 'lr 4/8/2005 23:15'!
testHash
	self assert: self instance hash isInteger.
	self assert: self instance hash = self instance hash.
	self deny: self instance hash = self instance copy hash.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 4/12/2005 21:35'!
testPropertiesAt
	self assert: (self instance propertyAt: #foo put: 'bar') = 'bar'.
	self assert: (self instance propertyAt: #foo) = 'bar'.
	self should: [ self instance propertyAt: #bar ] raise: Error.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 4/12/2005 21:34'!
testPropertiesAtIfAbsent
	self assert: (self instance propertyAt: #foo put: 'bar') = 'bar'.
	self assert: (self instance propertyAt: #foo ifAbsent: [ 'baz' ]) = 'bar'.
	self assert: (self instance propertyAt: #bar ifAbsent: [ 'baz' ]) = 'baz'.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 4/12/2005 21:34'!
testPropertiesAtIfAbsentPut
	self assert: (self instance propertyAt: #foo put: 'bar') = 'bar'.
	self assert: (self instance propertyAt: #foo ifAbsentPut: [ 'baz' ]) = 'bar'.
	self assert: (self instance propertyAt: #foo) = 'bar'.
	
	self assert: (self instance propertyAt: #bar ifAbsentPut: [ 'baz' ]) = 'baz'.
	self assert: (self instance propertyAt: #bar) = 'baz'.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 4/12/2005 21:35'!
testPropertiesAtPut
	self instance propertyAt: #foo put: 'bar'.
	self assert: (self instance propertyAt: #foo) = 'bar'.
	
	self instance propertyAt: #foo put: 'baz'.
	self assert: (self instance propertyAt: #foo) = 'baz'.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 4/12/2005 21:40'!
testPropertiesHas
	self instance instVarNamed: 'properties' put: nil.
	self deny: self instance hasProperties.
	
	self instance properties.
	self deny: self instance hasProperties.
	
	self instance propertyAt: #foo put: #bar.
	self assert: self instance hasProperties. ! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 4/12/2005 21:35'!
testPropertiesIncludes
	self deny: (self instance inlcudesProperty: #foo).
	self instance propertyAt: #foo put: 'bar'.
	self assert: (self instance inlcudesProperty: #foo).
	self deny: (self instance inlcudesProperty: #bar).! !

!MAObjectTest methodsFor: 'testing-identity' stamp: 'lr 4/9/2005 02:44'!
testReferenceStream
	| output input object |
	
	" every instance should be serializeable "
	output := ReferenceStream on: (RWBinaryOrTextStream on: ByteArray new).
	output nextPut: self instance.
	output close.
	
	" read back the serialized instance "
	input := ReferenceStream on: output contents readStream.
	object := input next.
	
	" different object reference, but equal object "
	self deny: self instance == object.
	self assert: self instance = object.
	
	" return the read in object (for subclasses) "
	^object.! !

!MAObjectTest methodsFor: 'testing' stamp: 'lr 4/12/2005 21:32'!
testSanity
	"If this test case fails, there is something wrong with the setup of the test-case."
	
	self assert: self instance class = self testedClass.! !

!MAObjectTest methodsFor: 'testing-identity' stamp: 'lr 4/8/2005 23:19'!
testSetElement
	| set |
	set := Set new.
	
	set add: self instance.
	self assert: set size = 1.
	self assert: (set includes: self instance).

	set add: self instance.
	self assert: set size = 1.
	self assert: (set includes: self instance).
			
	set add: self instance copy.
	self assert: set size = 2.
	self assert: (set includes: self instance).! !

!MAObjectTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MAObject! !

MAObjectTest subclass: #MARelationTest
	instanceVariableNames: 'relation'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

MARelationTest subclass: #MABasicRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MABasicRelationTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^true! !

!MABasicRelationTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MABasicRelation! !

MABasicRelationTest subclass: #MAConstantRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MAConstantRelationTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MAConstantRelationTest methodsFor: 'testing' stamp: 'lr 4/13/2005 20:01'!
testFailsFalse
	self fails: self false.
	! !

!MAConstantRelationTest methodsFor: 'testing' stamp: 'lr 4/13/2005 20:00'!
testSatisfiesTrue
	self satisfies: self true.
	! !

!MAConstantRelationTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MAConstantRelation! !

MABasicRelationTest subclass: #MASelectorRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MASelectorRelationTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MASelectorRelationTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MASelectorRelation! !

MARelationTest subclass: #MAComposedRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

MAComposedRelationTest subclass: #MAAllRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MAAllRelationTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MAAllRelationTest methodsFor: 'testing' stamp: 'lr 4/12/2005 22:22'!
testNone
	self satisfies: self relation.! !

!MAAllRelationTest methodsFor: 'testing' stamp: 'lr 4/12/2005 22:19'!
testOne
	self satisfies: self relation & self true.
	self fails: self relation & self false.! !

!MAAllRelationTest methodsFor: 'testing' stamp: 'lr 4/12/2005 22:18'!
testTwo
	self satisfies: self true & self true.
	self fails: self true & self false.
	self fails: self false & self true.
	self fails: self false & self false.! !

!MAAllRelationTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MAAllRelation! !

MAComposedRelationTest subclass: #MAAnyRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MAAnyRelationTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MAAnyRelationTest methodsFor: 'testing' stamp: 'lr 4/12/2005 22:22'!
testNone
	self fails: self relation.! !

!MAAnyRelationTest methodsFor: 'testing' stamp: 'lr 4/12/2005 22:19'!
testOne
	self satisfies: self relation | self true.
	self fails: self relation | self false.! !

!MAAnyRelationTest methodsFor: 'testing' stamp: 'lr 4/12/2005 22:19'!
testTwo
	self satisfies: self true | self true.
	self satisfies: self true | self false.
	self satisfies: self false | self true.
	self fails: self false | self false.! !

!MAAnyRelationTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MAAnyRelation! !

!MAComposedRelationTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^true! !

!MAComposedRelationTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MAComposedRelation! !

MAComposedRelationTest subclass: #MANoneRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MANoneRelationTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^false! !

!MANoneRelationTest methodsFor: 'testing' stamp: 'lr 4/12/2005 22:22'!
testNone
	self satisfies: self relation.! !

!MANoneRelationTest methodsFor: 'testing' stamp: 'lr 4/12/2005 22:21'!
testOne
	self fails: self relation !! self true.
	self satisfies: self relation !! self false.! !

!MANoneRelationTest methodsFor: 'testing' stamp: 'lr 4/12/2005 22:19'!
testTwo
	self fails: self true !! self true.
	self fails: self true !! self false.
	self fails: self false !! self true.
	self satisfies: self false !! self false.! !

!MANoneRelationTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MANoneRelation! !

!MARelationTest class methodsFor: 'testing' stamp: 'lr 4/14/2005 13:44'!
isAbstract
	^true! !

!MARelationTest methodsFor: 'utilities' stamp: 'lr 4/12/2005 22:32'!
fails: aRelation
	self deny: (aRelation isSatisfiedBy: self).! !

!MARelationTest methodsFor: 'constants' stamp: 'lr 4/13/2005 19:58'!
false
	^MAConstantRelation false.! !

!MARelationTest methodsFor: 'accessing' stamp: 'lr 4/9/2005 16:44'!
instance
	^relation! !

!MARelationTest methodsFor: 'accessing' stamp: 'lr 4/9/2005 16:44'!
relation
	^relation! !

!MARelationTest methodsFor: 'private' stamp: 'lr 4/9/2005 16:43'!
relationInstance
	^self testedClass new.! !

!MARelationTest methodsFor: 'utilities' stamp: 'lr 4/12/2005 22:32'!
satisfies: aRelation
	self assert: (aRelation isSatisfiedBy: self).! !

!MARelationTest methodsFor: 'running' stamp: 'lr 4/12/2005 22:07'!
setUp
	super setUp.
	relation := self relationInstance.! !

!MARelationTest methodsFor: 'private' stamp: 'lr 4/14/2005 13:44'!
testedClass
	^MARelation! !

!MARelationTest methodsFor: 'constants' stamp: 'lr 4/13/2005 19:57'!
true
	^MAConstantRelation true.! !

!MATestCase class methodsFor: 'private' stamp: 'lr 4/9/2005 16:27'!
buildTestClassFor: aClass
	| thisName thisClass thisCategory parentClass |
	thisName := (aClass name , 'Test') asSymbol.
	thisClass := Smalltalk classNamed: thisName.
	thisCategory := 'Magritte-Tests-' , (aClass category copyAfterLast: $-).
	parentClass := self = thisClass
		ifTrue: [ self superclass ]
		ifFalse: [ Smalltalk classNamed: (aClass superclass name , 'Test') asSymbol ].
	(thisName beginsWith: 'MA') ifFalse: [ ^self ].
	thisClass := parentClass 
		subclass: thisName
		instanceVariableNames: (thisClass isNil 
			ifFalse: [ thisClass instanceVariablesString ]
			ifTrue: [ String new ])
		classVariableNames: ''
		poolDictionaries: ''
		category: thisCategory.
	thisClass compile: 'testedClass
	^' , aClass name classified: #private.
	thisClass class compile: 'isAbstract
	^' , aClass isAbstract asString classified: #testing.
	aClass subclassesDo: [ :each | self buildTestClassFor: each ].! !

!MATestCase class methodsFor: 'accessing' stamp: 'lr 4/8/2005 22:06'!
shouldInheritSelectors
	^true! !

!MATestCase methodsFor: 'accessing' stamp: 'lr 4/8/2005 08:49'!
notifications
	notifications isNil
		ifTrue: [ self notifications: OrderedCollection new ].
	^notifications.! !

!MATestCase methodsFor: 'accessing' stamp: 'lr 4/8/2005 08:49'!
notifications: aCollection
	notifications := aCollection.! !

!MATestCase methodsFor: 'running' stamp: 'lr 4/8/2005 08:48'!
performTest
	[ super performTest ]
		on: MANotification
		do: [ :notification |
			self notifications add: notification.
			notification resume ].! !

!MATestCase methodsFor: 'running' stamp: 'lr 4/8/2005 08:48'!
setUp
	super setUp.
	self notifications: OrderedCollection new.! !
